@@ -4,13 +4,9 @@ from .helpers.std import Std
 
 class SubMangaOnline(Provider, Std):
 
-    def get_archive_name(self) -> str:
-        idx = self.get_chapter_index().split('.')
-        return self.normal_arc_name(idx)
-
     def get_chapter_index(self) -> str:
         re = self.re.compile(r'/manga/[^/]+/(\d+(?:\.\d+)?)')
-        return re.search(self.chapter).group(1)
+        return re.search(self.chapter).group(1).replace('.', '-')
 
     def get_main_content(self):
         return self._get_content('{}/manga/{}')
